Struct jupiter_amm_interface::SwapParams
source · pub struct SwapParams<'a, 'b> {
pub in_amount: u64,
pub out_amount: u64,
pub source_mint: Pubkey,
pub destination_mint: Pubkey,
pub source_token_account: Pubkey,
pub destination_token_account: Pubkey,
pub token_transfer_authority: Pubkey,
pub open_order_address: Option<Pubkey>,
pub quote_mint_to_referrer: Option<&'a QuoteMintToReferrer>,
pub jupiter_program_id: &'b Pubkey,
pub missing_dynamic_accounts_as_default: bool,
}Fields
in_amount: u64out_amount: u64source_mint: Pubkeydestination_mint: Pubkeysource_token_account: Pubkeydestination_token_account: PubkeyThis can be the user or the program authority over the source_token_account.
open_order_address: Option<Pubkey>quote_mint_to_referrer: Option<&'a QuoteMintToReferrer>jupiter_program_id: &'b Pubkeymissing_dynamic_accounts_as_default: boolInstead of returning the relevant Err, replace dynamic accounts with the default Pubkey This is useful for crawling market with no tick array
Implementations
sourceimpl<'a, 'b> SwapParams<'a, 'b>
impl<'a, 'b> SwapParams<'a, 'b>
sourcepub fn placeholder_account_meta(&self) -> AccountMeta
pub fn placeholder_account_meta(&self) -> AccountMeta
A placeholder to indicate an optional account or used as a terminator when consuming remaining accounts Using the jupiter program id